summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2006-04-17 14:33:23 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2009-04-06 16:09:04 -0500
commit629330e761dc23c95e65156abb8c39fc6c594382 (patch)
tree5a37e27f17f2e45a2fe87a24bd86f77a0d0244db /png.h
parentb511b60aaa2b1e425213dd96d0a40f7626980079 (diff)
downloadlibpng-629330e761dc23c95e65156abb8c39fc6c594382.tar.gz
Imported from libpng-1.2.10beta6.tarv1.2.10beta6
Diffstat (limited to 'png.h')
-rw-r--r--png.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/png.h b/png.h
index 0fdd62798..787e98ee4 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.2.10beta5 - April 17, 2006
* Copyright (c) 1998-2006 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -9,7 +9,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.2.10beta5 - April 17, 2006: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -146,7 +146,7 @@
* If you modify libpng you may insert additional notices immediately following
* this sentence.
*
* libpng versions 1.2.6, August 15, 2004, through 1.2.10beta5, April 17, 2006, are
* Copyright (c) 2004, 2006 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -264,7 +264,7 @@
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.2.10beta5 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -320,9 +320,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.2.10beta5"
+#define PNG_LIBPNG_VER_STRING "1.2.10beta6"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.2.10beta5 - April 17, 2006 (header)\n"
+ " libpng version 1.2.10beta6 - April 17, 2006 (header)\n"
#define PNG_LIBPNG_VER_SONUM 0
#define PNG_LIBPNG_VER_DLLNUM 13
@@ -334,7 +334,7 @@
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero: */
-#define PNG_LIBPNG_VER_BUILD 5
+#define PNG_LIBPNG_VER_BUILD 6
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -1364,7 +1364,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_2_10beta5;
+typedef png_structp version_1_2_10beta6;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.2.10beta5 - April 17, 2006
+ * libpng version 1.2.10beta6 - April 17, 2006
* Copyright (c) 1998-2006 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -9,7 +9,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.2.10beta5 - April 17, 2006: Glenn
+ * libpng versions 0.97, January 1998, through 1.2.10beta6 - April 17, 2006: Glenn
* See also "Contributing Authors", below.
*
@@ -146,7 +146,7 @@
* this sentence.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.2.10beta5, April 17, 2006, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.2.10beta6, April 17, 2006, are
* Copyright (c) 2004, 2006 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -264,7 +264,7 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.2.10beta5 are Y2K compliant. It is my belief that earlier
+ * upward through 1.2.10beta6 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*